@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2002-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -28,7 +28,11 @@
 #include "atom.h"
 #include "atomsdlg.h"
 #include "document.h"
-#include <chemistry/element.h>
+#ifdef GCU_OLD_VER
+#	include <chemistry/element.h>
+#else
+#	include <gcu/element.h>
+#endif
 #include <list>
 #include <string>
 
